FieldCommand (py4j-java 0.10.9.7 API)

Package py4j.commands

## Class FieldCommand

- java.lang.Object
- - py4j.commands.AbstractCommand
  - - py4j.commands.FieldCommand

- All Implemented Interfaces:
    `Command`

      public class FieldCommand
      extends AbstractCommand

  A FieldCommand is responsible for accessing and setting fields of objects.

- - ### Field Summary

    Fields
    Modifier and Type | Field | Description
    --- | --- | ---
    `static java.lang.String` | `FIELD_COMMAND_NAME` |
    `static java.lang.String` | `FIELD_GET_SUB_COMMAND_NAME` |
    `static java.lang.String` | `FIELD_SET_SUB_COMMAND_NAME` |

    - ### Fields inherited from class py4j.commands.AbstractCommand

      `commandName, connection, gateway`

  - ### Constructor Summary

    Constructors
    Constructor | Description
    --- | ---
    `FieldCommand()` |

  - ### Method Summary

    All Methods Instance Methods Concrete Methods
    Modifier and Type | Method | Description
    --- | --- | ---
    `void` | `execute​(java.lang.String commandName, java.io.BufferedReader reader, java.io.BufferedWriter writer)` |
    `void` | `init​(Gateway gateway, Py4JServerConnection connection)` | Called when a command instance is created and assigned to a connection.

    - ### Methods inherited from class py4j.commands.AbstractCommand

      `getArguments, getCommandName, getStringArguments, invokeMethod`

    - ### Methods inherited from class java.lang.Object

      `clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

- - ### Field Detail

    - #### FIELD_COMMAND_NAME

          public static final java.lang.String FIELD_COMMAND_NAME

      See Also:
        Constant Field Values

    - #### FIELD_GET_SUB_COMMAND_NAME

          public static final java.lang.String FIELD_GET_SUB_COMMAND_NAME

      See Also:
        Constant Field Values

    - #### FIELD_SET_SUB_COMMAND_NAME

          public static final java.lang.String FIELD_SET_SUB_COMMAND_NAME

      See Also:
        Constant Field Values

  - ### Constructor Detail

    - #### FieldCommand

          public FieldCommand()

  - ### Method Detail

    - #### execute

          public void execute​(java.lang.String commandName,
                              java.io.BufferedReader reader,
                              java.io.BufferedWriter writer)
                       throws Py4JException,
                              java.io.IOException

      Specified by:
        `execute` in interface `Command`
      Specified by:
        `execute` in class `AbstractCommand`
      Parameters:
        `commandName` - The command name that was extracted of the command.
        `reader` - The reader from which to read the command parts. Each command part are expected to be on a separate line and readable through `BufferedReader.readLine()`.
        `writer` - The writer to which the return value should be written.
      Throws:
        `Py4JException` - If an error occurs while executing the command. All exceptions except IOException caused by the reader and the writer should be wrapper in a `Py4JException` instance.
        `java.io.IOException` - If an error occurs while using the reader or the writer.

    - #### init

          public void init​(Gateway gateway,
                           Py4JServerConnection connection)

      Description copied from interface: `Command`

      Called when a command instance is created and assigned to a connection.

      Specified by:
        `init` in interface `Command`
      Overrides:
        `init` in class `AbstractCommand`
        `connection` - the `Py4JServerConnection` this socket is assigned to